/*
 * Vifir - An electronic flight bag wannabe utility for aircraft pilots
 * Copyright (C) 2009 David Ludlow
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * dave@adsllc.com, PO Box 13070, Toledo, OH 43623
 */

#ifndef IMPORTDTPPDVD_H_
#define IMPORTDTPPDVD_H_

#include <string>
#include <time.h>
#include <libxml++/libxml++.h>
#include <gtkmm/window.h>
#include <gtkmm/progressbar.h>
#include <gtkmm/button.h>
#include <libglademm.h>
#include "Config.h"
#include "ApproachPlate.h"
#include "DataStore.h"
#include "OverwriteFileDialog.h"

class ImportdTPPDVD
{
public:
	ImportdTPPDVD(Config *Cfg, std::string *GladeFilename, DataStore *Data);
	~ImportdTPPDVD();

	int Run();
	bool ConfirmData(std::string Volume, time_t EffectiveFrom, time_t EffectiveTo);

	const xmlpp::Node* ParseXmlInit(std::string Filename);
	void ParseXmlMetadata(const xmlpp::Node* Root);
	void ParseXmlState(const xmlpp::Node* State);
	void ParseXmlCity(const xmlpp::Node* City);
	void ParseXmlAirport(const xmlpp::Node* Airport);
	void ParseXmlRecord(const xmlpp::Node* Record, Airport *DSAirport);
	bool CopyImageFile(std::string ImgSrcPath,std::string DestDir);

private:
	static const double CopyProgressFrac=0.9;
	static const double ParseProgressFrac=0.1;

	Glib::RefPtr<Gnome::Glade::Xml> refXml;
	Config *Cfg;
	std::string *GladeFilename;
	Gtk::Window *ProgressWindow;
	Gtk::ProgressBar *ProgressBar,*SubProgressBar;
	Gtk::Button *CancelButton;
	int BytesRead,BytesAvail;
	bool CancelFlag;
	DataStore *Data;
	Volume *VolData;
	ApproachPlate Partial;	/* Fill this in as we gather data */
	xmlpp::DomParser Parser;
	std::string ImportVolume;
	time_t ImportEffectiveFrom,ImportEffectiveTo;
	std::vector<ApproachPlate*> *ApproachPlates;
	OverwriteFileDialog *OFDialog;

	void on_CancelButton_clicked();
};

#endif /*IMPORTDTPPDVD_H_*/
